# Changelog

## Version 1.1.0
- Improve nvme slot detection.
- Remove python 3.12 exclusive feature.
- Fix whitespace issue in logo.
- **Full Changelog**: [v1.0.1...v1.1.0](https://github.com/not-a-feature/wd_fw_update/compare/v1.0.1...v1.1.0)

## Version 1.0.1
- Add message and improve docs.
- **Full Changelog**: [v1.0.0...v1.0.1](https://github.com/not-a-feature/wd_fw_update/compare/v1.0.0...v1.0.1)

## Version 1.0.0 (initial release)

- Initial release
